@@ -554,8 +554,8 @@ class Router(BaseRouter[WSGIApp]):
 
     ```python
     applications = Router(
-        ("/static/{filepath:path}", static_files),
-        ("/api/{any:path}", api_app),
+        ("/static/{filepath:any}", static_files),
+        ("/api/{_:any}", api_app),
         ("/about/{name}", about_page, "about"),
         ("/", homepage, "homepage"),
     )
